@@ -61,14 +61,15 @@ Because Fiona collections are context managers, they are closed and (in
 writing modes) flush contents to disk when their ``with`` blocks end.
 """
 
-__version__ = "0.8"
+__all__ = []
+__version__ = "0.9"
 
 import os
 
-from fiona.collection import Collection
+from fiona.collection import Collection, supported_drivers
 
 
-def collection(path, mode='r', driver=None, schema=None, crs=None):
+def open(path, mode='r', driver=None, schema=None, crs=None):
     
     """Open file at ``path`` in ``mode`` "r" (read), "a" (append), or
     "w" (write) and return a ``Collection`` object.
@@ -88,6 +89,14 @@ def collection(path, mode='r', driver=None, schema=None, crs=None):
        'no_defs': True}
     
     """
+    # Fail immediately if driver and mode are unsupported.
+    if driver:
+        if driver not in supported_drivers:
+            raise ValueError(
+                "Invalid or unsupported driver '%s'" % driver )
+        elif mode not in supported_drivers[driver]:
+            raise ValueError(
+                "Invalid driver mode '%s'" % mode )
     if mode in ('a', 'r'):
         if not os.path.exists(path):
             raise OSError("Nonexistent path '%s'" % path)
@@ -107,3 +116,5 @@ def collection(path, mode='r', driver=None, schema=None, crs=None):
         raise ValueError("Invalid mode: %s" % mode)
     return c
 
+collection = open
+
